@@ -6,6 +6,7 @@ import os
 import matplotlib.pyplot as plt
 from scipy.optimize import curve_fit
 from . import extra_funcs as ef
+from copy import deepcopy
 
 exval, exUnis = {}, {}
 
@@ -116,6 +117,7 @@ class table:
             if not ef.isUncertain(self.data.columns[-1]):
                 self.data.insert(len(self.data.columns), ef.delt(
                     self.data.columns[-1]), [0 for i in range(len(self.data))])
+        self.data.columns = list(map(str, self.data.columns))
 
     def __repr__(self):
         dat = [c for c in list(self.data) if 'Delta' not in c]
@@ -324,7 +326,8 @@ class table:
             if str(self.units[col].SIval) in ["1", '1.00000000000000']:
                 names.append("${}$".format(col))
             else:
-                names.append("${}$ ({})".format(col, self.units[col].symb))
+                names.append("${}$ {{$\rm({})$}}".format(
+                    sp.latex(sp.sympify(ef.preSymp(col))), str(self.units[col])))
         exp.columns = names
         latex = exp.to_latex(index=False)\
             .replace("\\textbackslash ", "\\")\
@@ -342,7 +345,7 @@ class table:
             .replace("l" * len(exp.columns), "|" + "c|" * len(exp.columns))\
             .replace("pourcent", r"\%")\
             .replace("$omega", r"$\omega")
-        with open(r"tableaux\{}.tex".format(name), "w+") as final:
+        with open(r"tables\{}.tex".format(name), "w+") as final:
             final.write(latex)
 
     def fixUnits(self):
@@ -375,16 +378,22 @@ class table:
         self.data.insert(index * 2, name, df[name], False)
         self.data.insert(index * 2 + 1, ef.delt(name), df[ef.delt(name)], False)
 
-    def plot(self, xn, yn, fig_ax = None, **kwargs):
-        if fig_ax = None:
+    def plot(self, xn, yn, fig_ax=None, **kwargs):
+        if fig_ax == None:
             fig_ax = plt.figure(), plt.gca()
         fig, ax = fig_ax
-        ax.errorbar(*self[[xn, yn, ef.delt(yn), ef.delt(xn)]].T, ".", **kwargs)
-        plt.set_xlabel((ef.ax_name(self, xn))
-        plt.set_ylabel((ef.ax_name(self, yn))
+
+        dt = self.copy()
+        if xn not in self.data.columns:
+            dt.newCol(xn, xn)
+        if yn not in self.data.columns:
+            dt.newCol(yn, yn)
+        ax.errorbar(*dt[[xn, yn, ef.delt(yn), ef.delt(xn)]].T, ".", **kwargs)
+        ax.set_xlabel(ef.ax_name(dt, xn))
+        ax.set_ylabel(ef.ax_name(dt, yn))
         # plt.legend()
 
-    def fit(self, func, xn, yn, show=True, maxfev=1000, **kargs):
+    def fit(self, func, xn, yn, fig_ax=None, show=True, p0=None, maxfev=1000, **kwargs):
         """
         return optimal parameters of a function fitted on data
 
@@ -402,13 +411,18 @@ class table:
 
         (maxfev) Maximum number of itteration to find optimals parameters
         """
-        x0 = kargs["x0"] if "x0" in kargs else None
-        popt, pcov = curve_fit(func, *self[[xn, yn]].T, x0, maxfev=maxfev)
+        if fig_ax == None:
+            fig_ax = plt.figure(), plt.gca()
+        fig, ax = fig_ax
+        popt, pcov = curve_fit(func, *self[[xn, yn]].T, p0=p0, maxfev=maxfev)
+        results = np.array([np.array([popt, np.sqrt(pcov.diagonal())]).T.flatten()])
+        dt = table('', data=results, AutoInsert=False)
         if show:
-            self.plot(xn, yn, label="Données")
-            plt.plot(self[xn], func(self[xn], *popt), label="fit")
-            plt.legend()
-        return popt, pcov
+            x = np.linspace(*ef.extrem(self[xn]), 1000)
+            self.plot(xn, yn, label="Données", fig_ax=fig_ax, **kwargs)
+            ax.plot(x, func(x, *popt), label="fit")
+            ax.legend()
+        return dt
 
     def append(self, name, data, incert=None, pos=None, units="1"):
         if pos is None:
@@ -419,6 +433,9 @@ class table:
         self.data.insert(pos, name, data)
         self.data.insert(pos + 1, ef.delt(name), incert)
         self.fixUnits()
+    
+    def copy(self):
+        return deepcopy(self)
 
 
 def defVal(vals):
